> [!IMPORTANT]
> 文档已经迁移至开源[储存库 pdfdeal-docs](https://github.com/Menghuan1918/pdfdeal-docs)，请在此处查看[在线文档](https://menghuan1918.github.io/pdfdeal-docs/zh/)。

如您在查找`V0.1.x`版本的使用文档，请[参见此处](doc2x_old_cn.md)